@@ -1,8 +1,8 @@
 use strict;
 use warnings;
 package Pod::Coverage::TrustPod;
-BEGIN {
-  $Pod::Coverage::TrustPod::VERSION = '0.100000';
+{
+  $Pod::Coverage::TrustPod::VERSION = '0.100002';
 }
 use base 'Pod::Coverage::CountParents';
 # ABSTRACT: allow a module's pod to contain Pod::Coverage hints
@@ -53,7 +53,7 @@ sub _trustme_check {
     {}
   );
 
-  return grep { $sym =~ /$_/ } @{ $self->{trustme} }, keys %$from_pod;
+  return grep { $sym =~ /\A$_\z/ } @{ $self->{trustme} }, keys %$from_pod;
 }
 
 1;
@@ -67,7 +67,7 @@ Pod::Coverage::TrustPod - allow a module's pod to contain Pod::Coverage hints
 
 =head1 VERSION
 
-version 0.100000
+version 0.100002
 
 =head1 DESCRIPTION
 
@@ -114,7 +114,12 @@ Here is a sample Perl module:
 This file would report full coverage, because any non-empty lines inside a
 block of POD targeted to Pod::Coverage are treated as C<trustme> patterns.
 Leading and trailing whitespace is stripped and the remainder is treated as a
-regular expression.
+regular expression anchored at both ends.
+
+Remember, anywhere you could use C<=begin> and C<=end> as above, you could
+instead write:
+
+  =for Pod::Coverage foo
 
 =head1 AUTHOR
 
@@ -122,7 +127,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
